PduError

Enum PduError 

#[repr(u32)]
pub enum PduError {
Show 45 variants StatusNoError = 0, FctFailed = 1, Reserved1 = 16, CommPcToVciFailed = 17, PduApiNotConstructed = 32, SharingViolation = 33, ResourceBusy = 48, ResourceTableChanged = 49, ResourceError = 50, CllNotConnected = 64, CllNotStarted = 65, InvalidParameters = 80, InvalidHandle = 96, ValueNotSupported = 97, IdNotSupported = 98, ComParamNotSupported = 99, ComParamLocked = 100, TxQueueFull = 112, EventQueueEmpty = 113, VoltageNotSupported = 128, MuxRscNotSupported = 129, CableUnknown = 130, NoCableDetected = 131, CllConnected = 132, TempParamNotAllowed = 144, RscLocked = 160, RscLockedByAnotherCll = 161, RscNotLocked = 162, ModuleNotConnected = 163, ApiSwOutOfDate = 164, ModuleFwOutOfDate = 165, PinNotConnected = 166, IpProtocolNotSupported = 176, DoIpRoutingActivationFailed = 177, DoIpRoutingActivationAuthFailed = 178, DoIpAmbiguousLogicalAddress = 179, DoIpRoutineActivationInvalidSrcAddress = 180, DoIpRoutingActivationNoDataSocketAvailable = 181, DoIpRoutineActivationSourceAddressChanged = 182, DoIpRoutingActivationSourceAddressInUse = 183, DoIpRoutineActivationConfirmationRejected = 184, DoIpRoutineActivationTypeUnsupported = 185, DoIpRoutineActivationResponseCodeUnknown = 186, DoIpRoutingActivationResponseTimeout = 187, DoIpResponseTimeout = 188,
}
Function return values

Variants



StatusNoError = 0

No Error (Function call OK)



FctFailed = 1

Function call failed (Generic failure)



Reserved1 = 16

Reserved for ISO 22900-2



CommPcToVciFailed = 17

Communication failed between host and MVCI



PduApiNotConstructed = 32

PDU API has not yet been constructed



SharingViolation = 33

PDU Destruct was not called before another PDU Construct



ResourceBusy = 48

Resource is already in use



ResourceTableChanged = 49

Resource table changed



ResourceError = 50

Generic resource error



CllNotConnected = 64

ComLogicalLink cannot be offline and perform the requested action



CllNotStarted = 65

ComLogicalLink must be started to perform the requested action



InvalidParameters = 80

A parameter parsed into the function was invalid



InvalidHandle = 96

A handle provided was invalid



ValueNotSupported = 97

Option value was unsupported



IdNotSupported = 98

IOCTL Command ID was unsupported



ComParamNotSupported = 99

Communication parameter was unsupported



ComParamLocked = 100

Physical communication parameter cannot be changed as it is locked by another LogicalLink



TxQueueFull = 112

Transmit queue is full



EventQueueEmpty = 113

No more events are available to read



VoltageNotSupported = 128

IOCTL - Voltage value supplied is unsupported by the MVCI module



MuxRscNotSupported = 129

IOCTL - Pin or resource is not supported by the MVCI module



CableUnknown = 130

Cable attached to MVCI module is unknown



NoCableDetected = 131

No cable attached to the MVCI module



CllConnected = 132

ComLogicalLink is already connected



TempParamNotAllowed = 144

Physical Com parameters cannot be changes as a temporary one



RscLocked = 160

Resource is already locked



RscLockedByAnotherCll = 161

Resource is already locked by another ComLogicalLink



RscNotLocked = 162

Resource is already unlocked



ModuleNotConnected = 163

Module is not connected or ready



ApiSwOutOfDate = 164

API software is out of date



ModuleFwOutOfDate = 165

VCI firmware is out of date



PinNotConnected = 166

Requested pin is not routed by the MVCI’s cable



IpProtocolNotSupported = 176

IP protocol not supported



DoIpRoutingActivationFailed = 177

DoIP Routing activation failed (Generic failure)



DoIpRoutingActivationAuthFailed = 178

DoIP Routing activation failed - missing / wrong authentication



DoIpAmbiguousLogicalAddress = 179

DoIP Logical address is defined multiple times so it is ambiguous



DoIpRoutineActivationInvalidSrcAddress = 180

DoIP Routing activation failed - Unknown or invalid source address



DoIpRoutingActivationNoDataSocketAvailable = 181

DoIP Routing activation failed - No more free sockets available



DoIpRoutineActivationSourceAddressChanged = 182

DoIP Routing activation failed - The source address changed



DoIpRoutingActivationSourceAddressInUse = 183

DoIP Routing activation failed - Source address already in use



DoIpRoutineActivationConfirmationRejected = 184

DoIP Routing activation failed - Rejected confirmation



DoIpRoutineActivationTypeUnsupported = 185

DoIP Routing activation failed - Requested activation type was unsupported



DoIpRoutineActivationResponseCodeUnknown = 186

DoIP Routing activation failed - Response code was unknown



DoIpRoutingActivationResponseTimeout = 187

DoIP Routing activation failed - Timeout waiting for activation response



DoIpResponseTimeout = 188

DoIP general timeout

Implementations

Source

impl PduError

pub fn is_success(&self) -> bool

Returns true if the result indicates success according to the API.